@@ -10,6 +10,7 @@ import sqlite3
 import yaml
 import tornado.web
 import tornado.ioloop
+import momentpy
 
 
 EVENT_PUSH = "push"
@@ -260,9 +261,13 @@ class Handler(tornado.web.RequestHandler):
     def get(self):
         self.write("<table border=1 cellpadding=5>")
         self.write("<tr><th>Status</th><th>Commit</th><th>Author</th><th>Completed</th><th>Duration</th></tr>")
-        for push in self.application.db.all("SELECT * FROM push"):
+        for push in self.application.db.all("SELECT * FROM push ORDER BY created DESC LIMIT 25"):
+            started = datetime.datetime.strptime(push["started"], "%Y-%m-%d %H:%M:%S")
+            completed = datetime.datetime.strptime(push["completed"], "%Y-%m-%d %H:%M:%S")
+
             self.write("<tr><td>%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>" %
-                       (push["status"], push["commit"], push["author"], push["started"], push["completed"]))
+                       (push["status"], push["commit"], push["author"],
+                        completed, (completed - started).seconds))
         self.write("</table>")
 
     def json(self, obj, status=None):
